@@ -6,6 +6,7 @@ package Unicode::Precis::Preparation;
 use 5.006001;
 use strict;
 use warnings;
+no utf8;
 
 use base qw(Exporter);
 
@@ -18,7 +19,7 @@ our %EXPORT_TAGS = (
 );
 our @EXPORT_OK = @{$EXPORT_TAGS{'all'}};
 
-our $VERSION    = '0.000_03';
+our $VERSION    = '0.999_01';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;    # see L<perlmodstyle>
 
@@ -53,7 +54,7 @@ __END__
 
 =head1 NAME
 
-Unicode::Precis::Preparation - RFC 7564 PRECIS Framework - Preparation
+Unicode::Precis::Preparation - RFC 8264 PRECIS Framework - Preparation
 
 =head1 SYNOPSIS
 
@@ -66,6 +67,8 @@ Unicode::Precis::Preparation - RFC 7564 PRECIS Framework - Preparation
 L<Unicode::Precis::Preparation> prepares Unicode string or UTF-8 bytestring
 according to PRECIS framework.
 
+Note that the word "UTF-8" in this document is used in its proper meaning.
+
 =head2 Function
 
 =over
@@ -87,7 +90,7 @@ as UTF-8 sequence.
 
 =item $stringclass
 
-One of the constants C<ValidUTF8> (default), C<IdentifierClass> (see RFC 7564)
+One of the constants C<ValidUTF8> (default), C<IdentifierClass> (see RFC 8264)
 or C<FreeFormClass> (ditto).
 
 =item UnicodeVersion =E<gt> $version
@@ -126,7 +129,7 @@ and based on character for Unicode string.
 When the check fails, length of disallowed character.
 Length is C<1> to C<4> for bytestring,
 always C<1> for Unicode string
-and undefined value for invalid sequence.
+and undefined for invalid sequence.
 
 =item C<ord>
 
@@ -164,18 +167,42 @@ C<PVALID> means successful result.
 
 =back
 
-=head2 EXPORT
+=head2 Exports
 
 None are exported by default.
 prepare() and constants may be exported by C<:all> tag.
 
+=head1 RESTRICTIONS
+
+prepare() can not check Unicode string on EBCDIC platforms.
+
+=head2 Unicode versions
+
+=over
+
+=item String classes
+
+Derived properties are based on Unicode 6.3.0 or later.
+Some characters have imcompatible property values with Unicode prior to 6.0.0
+(See also RFC 6452).
+Property values of characters added by Unicode version after 6.3.0 can be
+changed in the future.
+
+=item Contextual rules
+
+Character properties checked by contextual rules are based on Unicode version
+that recent version of Perl supports.
+Some characters have imcompatible property values with Unicode 6.3.0.
+
+=back
+
 =head1 SEE ALSO
 
-L<Unicode::Precis> - coming late.
+L<Unicode::Precis>.
 
-RFC 7564 I<PRECIS Framework: Preparation, Enforcement, and Comparison of
+RFC 8264 I<PRECIS Framework: Preparation, Enforcement, and Comparison of
 Internationalized Strings in Application Protocols>.
-L<https://tools.ietf.org/html/rfc7564>.
+L<https://tools.ietf.org/html/rfc8264>.
 
 =head1 AUTHOR
 
@@ -183,10 +210,10 @@ Hatuka*nezumi - IKEDA Soji, E<lt>hatuka@nezumi.nuE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 by Hatuka*nezumi - IKEDA Soji
+Copyright (C) 2015, 2018 by Hatuka*nezumi - IKEDA Soji
 
 This library is free software; you can redistribute it and/or modify it
-under the same terms as Perl. For more details, see the full text of
+under the same terms as Perl itself. For more details, see the full text of
 the licenses at <http://dev.perl.org/licenses/>.
 
 This program is distributed in the hope that it will be
